==> gammaray_2.4.0.orig.tar.xz: gammaray-2.4.0/launcher/injector/injectorfactory.h <==
/*
  injectorfactory.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_INJECTORFACTORY_H
#define GAMMARAY_INJECTORFACTORY_H

#include "gammaray_launcher_export.h"

#include "abstractinjector.h"

namespace GammaRay {

class ProbeABI;

namespace InjectorFactory {

   GAMMARAY_LAUNCHER_EXPORT AbstractInjector::Ptr createInjector(const QString &name);

   AbstractInjector::Ptr defaultInjectorForLaunch(const ProbeABI &abi);

   AbstractInjector::Ptr defaultInjectorForAttach();

   /**
    * Returns the list of available injector types.
    */
   GAMMARAY_LAUNCHER_EXPORT QStringList availableInjectors();
}

}

#endif // GAMMARAY_INJECTORFACTORY_H

==> gammaray_2.6.0.orig.tar.xz: gammaray-2.6.0/launcher/injector/injectorfactory.h <==
/*
  injectorfactory.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_INJECTORFACTORY_H
#define GAMMARAY_INJECTORFACTORY_H

#include "gammaray_launcher_export.h"

#include "abstractinjector.h"

namespace GammaRay {
class ProbeABI;

namespace InjectorFactory {
GAMMARAY_LAUNCHER_EXPORT AbstractInjector::Ptr createInjector(const QString &name,
                                                              const QString &executableOverride
                                                                  = QString());

AbstractInjector::Ptr defaultInjectorForLaunch(const ProbeABI &abi);

AbstractInjector::Ptr defaultInjectorForAttach();

/**
 * Returns the list of available injector types.
 */
GAMMARAY_LAUNCHER_EXPORT QStringList availableInjectors();
}
}

#endif // GAMMARAY_INJECTORFACTORY_H
